% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CVE.R
\name{cve}
\alias{cve}
\alias{cve.call}
\title{Conditional Variance Estimator (CVE).}
\usage{
cve(formula, data, method = "simple", max.dim = 10L, ...)

cve.call(X, Y, method = "simple", nObs = sqrt(nrow(X)), h = NULL,
  min.dim = 1L, max.dim = 10L, k = NULL, tau = 1, tol = 0.001,
  epochs = 50L, attempts = 10L, logger = NULL)
}
\arguments{
\item{formula}{an object of class \code{"formula"} which is a symbolic
description of the model to be fitted.}

\item{data}{an optional data frame, containing the data for the formula if
supplied.}

\item{method}{specifies the CVE method variation as one of
\itemize{
     \item "simple" exact implementation as describet in the paper listed 
         below.
     \item "weighted" variation with addaptive weighting of slices.
}}

\item{max.dim}{upper bounds for \code{k}, (ignored if \code{k} is supplied).}

\item{...}{Parameters passed on to \code{cve.call}.}

\item{X}{data matrix with samples in its rows.}

\item{Y}{Responces (1 dimensional).}

\item{nObs}{parameter for choosing bandwidth \code{h} using
\code{\link{estimate.bandwidth}} (ignored if \code{h} is supplied).}

\item{min.dim}{lower bounds for \code{k}, (ignored if \code{k} is supplied).}

\item{k}{Dimension of lower dimensional projection, if given only the
specified dimension is estimated.}

\item{tau}{Initial step-size.}

\item{tol}{Tolerance for break condition.}

\item{epochs}{maximum number of optimization steps.}

\item{attempts}{number of arbitrary different starting points.}

\item{logger}{a logger function (only for addvanced user).}
}
\description{
TODO: reuse of package description and details!!!!
}
\examples{
library(CVE)

# create dataset
n <- 200
p <- 12
X <- matrix(rnorm(n * p), n, p)
B <- cbind(c(1, rep(0, p - 1)), c(0, 1, rep(0, p - 2)))
Y <- X \%*\% B
Y <- Y[, 1L]^2 + Y[, 2L]^2 + rnorm(n, 0, 0.3)

# Call the CVE method.
dr <- cve(Y ~ X)
round(dr[[2]]$B, 1)

}
\seealso{
For a detailed description of the formula parameter see
     [\code{\link{formula}}].
}
